@@ -2,8 +2,21 @@ package zfs
 
 import (
 	"encoding/json"
+	"testing"
 )
 
+func (t *Transaction) RegisterRevert(f func() error) {
+	t.registerRevert(f)
+}
+
+func (t *Transaction) CheckValid() {
+	t.checkValid()
+}
+
+func (t *Transaction) CancelPurged() {
+	<-t.done
+}
+
 // DatasetSlice enables sorting a slice of Dataset elements.
 // This is the element saved and compared against.
 type DatasetSlice struct {
@@ -27,9 +40,7 @@ func (s DatasetSlice) MarshalJSON() ([]byte, error) {
 	var dws []DatasetWithSource
 	for _, d := range s.DS {
 		datasetWS := DatasetWithSource{Dataset: d}
-		if s.IncludePrivate {
-			datasetWS.Sources = &datasetWS.sources
-		}
+		datasetWS.Sources = &datasetWS.sources
 		dws = append(dws, datasetWS)
 	}
 
@@ -46,11 +57,18 @@ func (s *DatasetSlice) UnmarshalJSON(b []byte) error {
 
 	for _, dw := range dws {
 		d := dw.Dataset
-		if s.IncludePrivate {
-			d.sources = *dw.Sources
-		}
+		d.sources = *dw.Sources
 		s.DS = append(s.DS, d)
 	}
 
 	return nil
 }
+
+// AssertNoZFSChildren checks that every dataset of a zfs object doesnt have any child.
+func AssertNoZFSChildren(t *testing.T, z *Zfs) {
+	for _, d := range z.allDatasets {
+		if len(*d.dZFS.DZFSChildren()) > 0 {
+			t.Errorf("%q has %d children left: %v", d.Name, len(*d.dZFS.DZFSChildren()), *d.dZFS.DZFSChildren())
+		}
+	}
+}
